@@ -67,7 +67,7 @@ _SEQDB = {
     '< <EM>'             : 'EM / Ctrl-Y',
     '< <SUB>'            : 'SUB / Ctrl-Z',
     '< <ESC>'            : 'ESC / Ctrl-[, Ctrl-3,  or Escape key',
-    '< <FS> '            : 'SUB / Ctrl-\\, Ctrl-4',
+    '< <FS> '            : 'FS / Ctrl-\\, Ctrl-4',
     '< <GS>'             : 'GS / Ctrl-], Ctrl-5',
     '< <RS>'             : 'RS / Ctrl-^, Ctrl-6',
     '< <US>'             : 'US / Ctrl-_, Ctrl-7',
@@ -286,8 +286,39 @@ _SEQDB = {
     '< CSI 201~'         : 'Terminate bracketed paste',
 
     """ output """
-    '> <NUL>'            : 'NUL / null character',
-    '> <BEL>'            : 'BEL / bell',
+    '< <NUL>'            : 'NUL / null character',
+    '< <SOH>'            : 'SOH / start of heading',
+    '< <STX>'            : 'STX / start of text',
+    '< <ETX>'            : 'ETX / end of text',
+    '< <EOT>'            : 'EOT / end of transmission',
+    '< <ENQ>'            : 'ENQ / enquiry',
+    '< <ACK>'            : 'ACK / jcknowledge',
+    '< <BEL>'            : 'BEL / bell',
+    '< <BS>'             : 'BS / back space',
+    '< <HT>'             : 'HT / character tabulation',
+    '< <NL>'             : 'LF / line feed',
+    '< <VT>'             : 'VT / line tabulation',
+    '< <FF>'             : 'FF / form feed',
+    '< <CR>'             : 'CR / carriage return',
+    '< <SO>'             : 'SO(LS1) / shift out (locking shift 1)',
+    '< <SI>'             : 'SI(LS0) / shift in (locking shift 0)',
+    '< <DLE>'            : 'DLE / data link escape',
+    '< <DC1>'            : 'DC1 / device control one',
+    '< <DC2>'            : 'DC2 / device control two',
+    '< <DC3>'            : 'DC3 / device control three',
+    '< <DC4>'            : 'DC4 / device control four',
+    '< <NAK>'            : 'NAK / negative acknowledge',
+    '< <SYN>'            : 'SYN / synchronous idle',
+    '< <ETB>'            : 'ETB / end of transmission block',
+    '< <CAN>'            : 'CAN / cancel',
+    '< <EM>'             : 'EM / end of medium',
+    '< <SUB>'            : 'SUB / substitute',
+    '< <ESC>'            : 'ESC / escape',
+    '< <FS> '            : 'FS(IS4) / file separator (Information separator four)',
+    '< <GS>'             : 'GS(IS3) / group separator (Information separator three)',
+    '< <RS>'             : 'RS(IS2) / record separator (Information separator two)',
+    '< <US>'             : 'US(IS1) / unit separator (Information separator one)',
+    '< <DEL>'            : 'DEL / delete',
     '> ESC P<ST>'        : 'DCS / device control string',
     '> ESC ]<ST>'        : 'OSC / operating system command',
     '> ESC ]0<ST>'       : 'OSC 0 / set icon name and window title',
@@ -881,21 +912,28 @@ def get():
 """
 
 import os
+import sys
 
 
+# get resource directory path ($HOME/.trachet)
 rcdir = os.path.join(os.getenv("HOME"), ".trachet")
+
 if not os.path.exists(rcdir):
+    # create resouce directory
     os.makedirs(rcdir)
 
+# get configure file path ($HOME/.trachet/conf.py)
 confpath = os.path.join(rcdir, "conf.py")
+
 if not os.path.exists(confpath):
+    # create default configured setting file
     f = open(confpath, "w")
     try:
         f.write(_DEFAULT_CONF)
     finally:
         f.close()
 
-import sys
+# add resource directory to default import directory
 sys.path.insert(0, rcdir)
 try:
     import conf
@@ -904,9 +942,10 @@ try:
 except:
     print str(sys.exc_info())
 finally:
-    sys.path.pop(0)
+    sys.path.remove(rcdir)
 
 
+# return reserved sequence map
 def get():
     return _SEQDB
 
