@@ -24,11 +24,16 @@ _DB = seqdb.get()
 
 
 def get_mnemonic(direction, f):
+    """
+    >>> get_mnemonic('=', 'O')
+    '<unknown>'
+    """
+
     key = "%s ESC N %s" % (direction, f)
     if key in _DB:
         mnemonic = _DB[key]
     else:
-        mnemonic = '<Unknown>'
+        mnemonic = '<unknown>'
     return mnemonic
 
 
@@ -51,6 +56,21 @@ def format(final, is_input, tracer, controller):
     result = template % (" ".join(context), mnemonic)
     return result
 
+
+def _test():
+    """
+    >>> _test()
+    test
+    <unknown>
+    """
+    global _DB
+    _DB = {'> ESC N O': 'test'}
+
+    print get_mnemonic('>', 'O')
+
+    print get_mnemonic('>', 'A')
+
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod()
