@@ -29,7 +29,7 @@ def get_mnemonic(direction, f):
     if key in _DB:
         mnemonic = _DB[key]
     else:
-        mnemonic = '<Unknown>'
+        mnemonic = '<unknown>'
     return mnemonic
 
 
@@ -54,6 +54,20 @@ def format(final, is_input, tracer, controller):
     return result
 
 
+def _test():
+    """
+    >>> _test()
+    test
+    <unknown>
+    """
+    global _DB
+    _DB = {'> ESC O O': 'test'}
+
+    print get_mnemonic('>', 'O')
+
+    print get_mnemonic('>', 'A')
+
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod()
